@@ -3,6 +3,9 @@
 #' Perform recommendation using Alternating Least Squares (ALS) matrix factorization.
 #'
 #' @template roxlate-ml-x
+#' @param formula Used when \code{x} is a \code{tbl_spark}. R formula as a character string or a formula.
+#' This is used to transform the input dataframe before fitting, see \link{ft_r_formula} for details.
+#' The ALS model requires a specific formula format, please use \code{rating_col ~ user_col + item_col}.
 #' @param rating_col Column name for ratings. Default: "rating"
 #' @param user_col Column name for user ids. Ids must be integers. Other numeric types are supported for this column, but will be cast to integers as long as they fall within the integer value range. Default: "user"
 #' @param item_col Column name for item ids. Ids must be integers. Other numeric types are supported for this column, but will be cast to integers as long as they fall within the integer value range. Default: "item"
@@ -54,7 +57,7 @@
 #' )
 #' movies_tbl <- sdf_copy_to(sc, movies)
 #'
-#' model <- ml_als(movies_tbl)
+#' model <- ml_als(movies_tbl, rating ~ user + item)
 #'
 #' ml_predict(model, movies_tbl)
 #'
@@ -62,17 +65,18 @@
 #' }
 #'
 #' @export
-ml_als <- function(x, rating_col = "rating", user_col = "user", item_col = "item",
+ml_als <- function(x, formula = NULL, rating_col = "rating", user_col = "user", item_col = "item",
                    rank = 10, reg_param = 0.1, implicit_prefs = FALSE, alpha = 1,
                    nonnegative = FALSE, max_iter = 10, num_user_blocks = 10,
                    num_item_blocks = 10, checkpoint_interval = 10,
                    cold_start_strategy = "nan", intermediate_storage_level = "MEMORY_AND_DISK",
                    final_storage_level = "MEMORY_AND_DISK", uid = random_string("als_"), ...) {
+  check_dots_used()
   UseMethod("ml_als")
 }
 
 #' @export
-ml_als.spark_connection <- function(x, rating_col = "rating", user_col = "user", item_col = "item",
+ml_als.spark_connection <- function(x, formula = NULL, rating_col = "rating", user_col = "user", item_col = "item",
                                     rank = 10, reg_param = 0.1, implicit_prefs = FALSE, alpha = 1,
                                     nonnegative = FALSE, max_iter = 10, num_user_blocks = 10,
                                     num_item_blocks = 10, checkpoint_interval = 10,
@@ -96,7 +100,7 @@ ml_als.spark_connection <- function(x, rating_col = "rating", user_col = "user",
     intermediate_storage_level = intermediate_storage_level,
     final_storage_level = final_storage_level
   ) %>%
-    ml_validator_als()
+    validator_ml_als()
 
   jobj <- invoke_new(x, "org.apache.spark.ml.recommendation.ALS", uid) %>%
     invoke("setRatingCol", .args[["rating_col"]]) %>%
@@ -111,15 +115,15 @@ ml_als.spark_connection <- function(x, rating_col = "rating", user_col = "user",
     invoke("setNumUserBlocks", .args[["num_user_blocks"]]) %>%
     invoke("setNumItemBlocks", .args[["num_item_blocks"]]) %>%
     invoke("setCheckpointInterval", .args[["checkpoint_interval"]]) %>%
-    maybe_set_param(
+    jobj_set_param(
       "setIntermediateStorageLevel", .args[["intermediate_storage_level"]],
       "2.0.0", "MEMORY_AND_DISK"
     ) %>%
-    maybe_set_param(
+    jobj_set_param(
       "setFinalStorageLevel", .args[["final_storage_level"]],
       "2.0.0","MEMORY_AND_DISK"
     ) %>%
-    maybe_set_param(
+    jobj_set_param(
       "setColdStartStrategy", .args[["cold_start_strategy"]],
       "2.2.0", "nan"
     )
@@ -128,7 +132,7 @@ ml_als.spark_connection <- function(x, rating_col = "rating", user_col = "user",
 }
 
 #' @export
-ml_als.ml_pipeline <- function(x, rating_col = "rating", user_col = "user", item_col = "item",
+ml_als.ml_pipeline <- function(x, formula = NULL, rating_col = "rating", user_col = "user", item_col = "item",
                                rank = 10, reg_param = 0.1, implicit_prefs = FALSE, alpha = 1,
                                nonnegative = FALSE, max_iter = 10, num_user_blocks = 10,
                                num_item_blocks = 10, checkpoint_interval = 10,
@@ -137,6 +141,7 @@ ml_als.ml_pipeline <- function(x, rating_col = "rating", user_col = "user", item
 
   stage <- ml_als.spark_connection(
     x = spark_connection(x),
+    formula = formula,
     rating_col = rating_col,
     user_col = user_col,
     item_col = item_col,
@@ -159,14 +164,18 @@ ml_als.ml_pipeline <- function(x, rating_col = "rating", user_col = "user", item
 }
 
 #' @export
-ml_als.tbl_spark <- function(x, rating_col = "rating", user_col = "user", item_col = "item",
+ml_als.tbl_spark <- function(x, formula = NULL, rating_col = "rating", user_col = "user", item_col = "item",
                              rank = 10, reg_param = 0.1, implicit_prefs = FALSE, alpha = 1,
                              nonnegative = FALSE, max_iter = 10, num_user_blocks = 10,
                              num_item_blocks = 10, checkpoint_interval = 10,
                              cold_start_strategy = "nan", intermediate_storage_level = "MEMORY_AND_DISK",
                              final_storage_level = "MEMORY_AND_DISK", uid = random_string("als_"), ...) {
+
+  formula <- ml_standardize_formula(formula)
+
   stage <- ml_als.spark_connection(
     x = spark_connection(x),
+    formula = formula,
     rating_col = rating_col,
     user_col = user_col,
     item_col = item_col,
@@ -186,21 +195,21 @@ ml_als.tbl_spark <- function(x, rating_col = "rating", user_col = "user", item_c
     ...
   )
 
-  stage %>%
-    ml_fit(x)
+  if (is.null(formula)) {
+    model_als <- stage %>%
+      ml_fit(x)
+  } else {
+    ml_construct_model_recommendation(
+      new_ml_model_als,
+      predictor = stage,
+      formula = formula,
+      dataset = x
+    )
+  }
 }
 
 # Validator
-ml_validator_als <- function(.args) {
-  .args <- ml_backwards_compatibility(.args, list(
-    rating.column = "rating_col",
-    user.column = "user_col",
-    item.column = "item_col",
-    regularization.parameter = "reg_param",
-    implicit.preferences = "implicit_prefs",
-    iter.max = "max_iter"
-  ))
-
+validator_ml_als <- function(.args) {
   .args[["rating_col"]] <- cast_string(.args[["rating_col"]])
   .args[["user_col"]] <- cast_string(.args[["user_col"]])
   .args[["item_col"]] <- cast_string(.args[["item_col"]])
@@ -222,11 +231,11 @@ ml_validator_als <- function(.args) {
 # Constructors
 
 new_ml_als <- function(jobj) {
-  new_ml_predictor(jobj, subclass = "ml_als")
+  new_ml_estimator(jobj, class = "ml_als")
 }
 
 new_ml_als_model <- function(jobj) {
-  new_ml_prediction_model(
+  new_ml_transformer(
     jobj,
     rank = invoke(jobj, "rank"),
     recommend_for_all_items = function(num_users) {
@@ -248,7 +257,7 @@ new_ml_als_model <- function(jobj) {
     user_col = invoke(jobj, "getUserCol"),
     item_col = invoke(jobj, "getItemCol"),
     prediction_col = invoke(jobj, "getPredictionCol"),
-    subclass = "ml_als_model")
+    class = "ml_als_model")
 }
 
 # Hideous hack
@@ -263,8 +272,14 @@ utils::globalVariables("explode")
 #'
 #' @export
 ml_recommend <- function(model, type = c("items", "users"), n = 1) {
-  if (spark_version(spark_connection(model)) < "2.2.0")
-    stop("`ml_recommend()`` is only support for Spark 2.2+.")
+
+  version <- spark_jobj(model) %>%
+    spark_connection() %>%
+    spark_version()
+
+  if (version < "2.2.0") stop("`ml_recommend()`` is only supported for Spark 2.2+.", call. = FALSE)
+
+  model <-  if (inherits(model, "ml_model_als")) model$model else model
 
   type <- match.arg(type)
   n <- cast_scalar_integer(n)
@@ -274,16 +289,3 @@ ml_recommend <- function(model, type = c("items", "users"), n = 1) {
     mutate(recommendations = explode(!!as.name("recommendations"))) %>%
     sdf_separate_column("recommendations")
 }
-
-#' @rdname ml_als
-#' @details \code{ml_als_factorization()} is an alias for \code{ml_als()} for backwards compatibility.
-#' @export
-ml_als_factorization <- function(x, rating_col = "rating", user_col = "user", item_col = "item",
-                                 rank = 10, reg_param = 0.1, implicit_prefs = FALSE, alpha = 1,
-                                 nonnegative = FALSE, max_iter = 10, num_user_blocks = 10,
-                                 num_item_blocks = 10, checkpoint_interval = 10,
-                                 cold_start_strategy = "nan", intermediate_storage_level = "MEMORY_AND_DISK",
-                                 final_storage_level = "MEMORY_AND_DISK", uid = random_string("als_"), ...) {
-  .Deprecated("ml_als")
-  UseMethod("ml_als")
-}
