@@ -143,8 +143,10 @@ spark_dependency_fallback <- function(spark_version, supported_versions) {
 sparklyr_jar_path <- function(spark_version) {
   if (spark_version < "2.0")
     scala_version <- "2.10"
-  else
+  else if (spark_version < "3.0")
     scala_version <- "2.11"
+  else
+    scala_version <- "2.12"
   spark_major_minor <- spark_version[1, 1:2]
 
   exact_jar <- sprintf("sparklyr-%s-%s.jar", spark_major_minor, scala_version)
@@ -152,9 +154,17 @@ sparklyr_jar_path <- function(spark_version) {
 
   if (exact_jar %in% all_jars) {
     system.file(file.path("java", exact_jar), package = "sparklyr")
+  } else if (exists(".test_on_spark_master", envir = .GlobalEnv)) {
+    exact_jar <- "sparklyr-master-2.12.jar"
+    system.file(file.path("java", exact_jar), package = "sparklyr")
   } else if (spark_version > "1.6") {
     # Spark is backwards compatible so we can use a new version with the latest jar
     all_versions <- sort(gsub("^sparklyr-|-[0-9]+\\.[0-9]+\\.jar$", "", all_jars), decreasing = T)
+
+    # Support preview versions and master builds
+    all_versions <- all_versions[all_versions != "master"]
+    all_versions <- gsub("-preview", "", all_versions)
+
     prev_versions <- all_versions[all_versions <= spark_version]
 
     dir(system.file("java", package = "sparklyr"),
