@@ -4,8 +4,6 @@ import java.io._
 import java.net.{InetAddress, ServerSocket}
 import java.util.Arrays
 
-import scala.util.Try
-
 import org.apache.spark.SparkContext
 import org.apache.spark.rdd.RDD
 import org.apache.spark.sql._
@@ -13,6 +11,8 @@ import org.apache.spark.sql.functions._
 import org.apache.spark.sql.types._
 import org.apache.spark.{SparkEnv, SparkException}
 
+import scala.util.Try
+
 object Utils {
 
   /**
@@ -419,13 +419,6 @@ object Utils {
     }.collect().last.getDouble(0)
   }
 
-  def zipDataFrames(sc: SparkContext, df1: DataFrame, df2: DataFrame) : DataFrame = {
-      val sqlContext = new org.apache.spark.sql.SQLContext(sc)
-      sqlContext.createDataFrame(
-        df1.rdd.zip(df2.rdd).map { case (r1, r2) => Row.merge(r1, r2) },
-        StructType(df1.schema ++ df2.schema))
-  }
-
   def unboxString(x: Option[String]) = x match {
     case Some(s) => s
     case None => ""
