@@ -1,20 +1,20 @@
 package sparklyr
 
+import java.nio.channels.Channels
+import scala.collection.JavaConverters._
+
+import org.apache.arrow.vector._
+import org.apache.arrow.vector.ipc.message.{ArrowRecordBatch, MessageSerializer}
+import org.apache.arrow.vector.ipc.WriteChannel
+
+import org.apache.spark.sql.types._
+import org.apache.spark.sql.util.ArrowUtils
+
 class ArrowBatchStreamWriter(
     schema: org.apache.spark.sql.types.StructType,
     out: java.io.OutputStream,
     timeZoneId: String) {
 
-  import java.nio.channels.Channels
-  import scala.collection.JavaConverters._
-
-  import org.apache.arrow.vector._
-  import org.apache.arrow.vector.ipc.message.{ArrowRecordBatch, MessageSerializer}
-  import org.apache.arrow.vector.ipc.WriteChannel
-
-  import org.apache.spark.sql.types._
-  import org.apache.spark.sql.execution.arrow.ArrowUtils
-
   val arrowSchema = ArrowUtils.toArrowSchema(schema, timeZoneId)
   val writeChannel = new WriteChannel(Channels.newChannel(out))
 
