@@ -5,14 +5,15 @@ test_requires("ggplot2")
 diamonds_tbl <- testthat_tbl("diamonds")
 
 test_that("the (serial) implementation of 'do' functions as expected", {
-  skip("need to investigate failure")
   test_requires("dplyr")
 
   R <- diamonds %>%
+    filter(color == "E" | color == "I", clarity == "SI1") %>%
     group_by(color, clarity) %>%
     do(model = lm(price ~ x + y + z, data = .))
 
   S <- diamonds_tbl %>%
+    filter(color == "E" | color == "I", clarity == "SI1") %>%
     group_by(color, clarity) %>%
     do(model = ml_linear_regression(., price ~ x + y + z))
 
@@ -27,13 +28,3 @@ test_that("the (serial) implementation of 'do' functions as expected", {
   }
 
 })
-
-test_that("ml routines handle 'data' argument with 'do'", {
-  skip("need to investigate failure")
-  test_requires("dplyr")
-
-  S <- diamonds_tbl %>%
-    group_by(color) %>%
-    do(model = ml_linear_regression(price ~ x + y + z, data = .))
-
-})
